@@ -20,7 +20,7 @@ gs <- as.list(sample(10:100, size=100, replace=TRUE))
 gs <- lapply(gs, function(n, p)
                    paste0("g", sample(1:p, size=n, replace=FALSE)), p)
 names(gs) <- paste0("gs", 1:length(gs))
-gsvaPar <- gsvaParam(X, gs)
+gsvaPar <- gsvaParam(X, gs, verbose=FALSE)
 gsva.es <- gsva(gsvaPar, verbose=FALSE)
 dim(gsva.es)
 gsva.es[seq.int(min(nRowsToPrint, nrow(gsva.es))),]
@@ -28,6 +28,6 @@ gsva.es[seq.int(min(nRowsToPrint, nrow(gsva.es))),]
 c2BroadSets <- c2BroadSets[c(grep("_UP$", names(c2BroadSets)),
                              grep("_DN$", names(c2BroadSets)))]
 firPar <- gsvaParam(geneExpCostaEtAl2021, c2BroadSets,
-                    minSize=10, maxSize=500)
+                    minSize=10, maxSize=500, verbose=FALSE)
 fir_es <- gsva(firPar, verbose=FALSE)
 assay(fir_es)[seq.int(min(nRowsToPrint, nrow(fir_es))),]
